Implementation of small area estimation using Hierarchical Bayesian (HB) Method when auxiliary variable measured with error. The 'rjags' package is employed to obtain parameter estimates.
Azka Ubaidillah, Muhammad Rifqi Mubarak
Muhammad Rifqi Mubarak rifqi.mubarak@bps.go.id
meHBNormalProduces HB estimators, standard error, random effect variance, coefficient and plot under normal distribution.
meHBtProduces HB estimators, standard error, random effect variance, coefficient and plot under student-t distribution.
Maintainer: Muhammad Rifqi Mubarak rifqi.mubarak@bps.go.id
Authors:
Azka Ubaidillah azka@stis.ac.id
Rao, J.N.K & Molina. (2015). Small Area Estimation 2nd Edition. New York: John Wiley and Sons, Inc <doi:10.1002/9781118735855>.
Ybarra, L.M. and Lohr, S. L. (2008). Small area estimation when auxiliary information is measured with error. Biometrika 95, 919-931 <doi:10.1093/biomet/asn048>.
Ntzoufras, I. (2009), Bayesian Modeling Using WinBUGS. 1st Edn., Wiley, New Jersey, ISBN-10: 1118210352.